@@ -1,5 +1,8 @@
+#ifdef NEED_MAKEFILE_EDIT
+#error you must first edit and customize the makefile to your platform
+#endif /* NEED_MAKEFILE_EDIT */
 char	netsh_id[]="\
-@(#)netsh.c (c) Copyright 1993, 1994 Hewlett-Packard Company. Version 2.1";
+@(#)netsh.c (c) Copyright 1993-2003 Hewlett-Packard Company. Version 2.2pl3";
 
 
 /****************************************************************/
@@ -11,7 +14,9 @@ char	netsh_id[]="\
 #include <sys/types.h>
 #ifndef WIN32
 #include <unistd.h>
+#ifndef __VMS
 #include <sys/ipc.h>
+#endif /* __VMS */
 #endif /* WIN32 */
 #include <fcntl.h>
 #include <errno.h>
@@ -20,12 +25,10 @@ char	netsh_id[]="\
 #include <stdlib.h>
 #include <ctype.h>
  /* the following four includes should not be needed ?*/
-#ifdef notdef
 #include <sys/time.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
-#endif /* notdef */
 
 #ifndef STRINGS
 #include <string.h>
@@ -51,6 +54,7 @@ double atof();
 #include "nettest_bsd.h"
 #ifdef DO_UNIX
 #include "nettest_unix.h"
+#include "sys/socket.h"
 #endif /* DO_UNIX */
 #ifdef DO_IPV6
 #include "nettest_ipv6.h"
@@ -61,16 +65,10 @@ double atof();
 /*									*/
 /************************************************************************/
 
- /* This define is only needed for HP-UX 7.x and earlier... */
-#ifdef HP
-#define bcopy(s,d,h) memcpy((d),(s),(h))
-#define bzero(p,h) memset((p),0,(h))
-#endif /* HP */
-
  /* Some of the args take optional parameters. Since we are using */
  /* getopt to parse the command line, we will tell getopt that they do */
  /* not take parms, and then look for them ourselves */
-#define GLOBAL_CMD_LINE_ARGS "A:a:b:CcdDf:F:H:hi:I:l:n:O:o:P:p:t:v:W:w:"
+#define GLOBAL_CMD_LINE_ARGS "A:a:b:CcdDf:F:H:hi:I:l:n:O:o:P:p:t:v:W:w:46"
 
 /************************************************************************/
 /*									*/
@@ -97,7 +95,7 @@ char	cmd_file[BUFSIZ];	/* name of the commands file		*/
 
 /* stuff to say where this test is going                                */
 char	host_name[HOSTNAMESIZE];	/* remote host name or ip addr  */
-char    test_name[64];			/* which test to run 		*/
+char    test_name[BUFSIZ];			/* which test to run 		*/
 short	test_port;			/* where is the test waiting    */
 
 /* the source of data for filling the buffers */
@@ -171,6 +169,9 @@ double interval;
 int	send_width;
 int     recv_width;
 
+/* address family */
+int	af = AF_INET;
+
 char netserver_usage[] = "\n\
 Usage: netserver [options] \n\
 \n\
@@ -492,7 +493,7 @@ scan_cmd_line(argc, argv)
       /* measure local cpu usage please. the user */
       /* may have specified the cpu rate as an */
       /* optional parm */
-      if (isdigit(argv[optind][0])){
+      if (argv[optind] && isdigit(argv[optind][0])){
 	/* there was an optional parm */
 	local_cpu_rate = (float)atof(argv[optind]);
 	optind++;
@@ -501,7 +502,7 @@ scan_cmd_line(argc, argv)
       break;
     case 'C':
       /* measure remote cpu usage please */
-      if (isdigit(argv[optind][0])){
+      if (argv[optind] && isdigit(argv[optind][0])){
 	/* there was an optional parm */
 	remote_cpu_rate = (float)atof(argv[optind]);
 	optind++;
@@ -546,82 +547,105 @@ scan_cmd_line(argc, argv)
   /* test specific options. this is a bit kludgy and if anyone has */
   /* a better solution, i would love to see it */
   if (optind != argc) {
-    if ((strcmp(test_name,"TCP_STREAM") == 0) || 
-	(strcmp(test_name,"TCP_RR") == 0) ||
-	(strcmp(test_name,"TCP_CRR") == 0) ||
+    if ((strcasecmp(test_name,"TCP_STREAM") == 0) || 
+#ifdef HAVE_SENDFILE
+	(strcasecmp(test_name,"TCP_SENDFILE") == 0) ||
+#endif /* HAVE_SENDFILE */
+	(strcasecmp(test_name,"TCP_MAERTS") == 0) ||
+	(strcasecmp(test_name,"TCP_RR") == 0) ||
+	(strcasecmp(test_name,"TCP_CRR") == 0) ||
 #ifdef DO_1644
-	(strcmp(test_name,"TCP_TRR") == 0) ||
+	(strcasecmp(test_name,"TCP_TRR") == 0) ||
 #endif /* DO_1644 */
 #ifdef DO_NBRR
-	(strcmp(test_name,"TCP_TRR") == 0) ||
+	(strcasecmp(test_name,"TCP_TRR") == 0) ||
 #endif /* DO_NBRR */
-	(strcmp(test_name,"UDP_STREAM") == 0) ||
-	(strcmp(test_name,"UDP_RR") == 0))
+	(strcasecmp(test_name,"UDP_STREAM") == 0) ||
+	(strcasecmp(test_name,"UDP_RR") == 0))
       {
 	scan_sockets_args(argc, argv);
       }
 #ifdef DO_DLPI
-    else if ((strcmp(test_name,"DLCO_RR") == 0) ||
-	     (strcmp(test_name,"DLCL_RR") == 0) ||
-	     (strcmp(test_name,"DLCO_STREAM") == 0) ||
-	     (strcmp(test_name,"DLCL_STREAM") == 0))
+    else if ((strcasecmp(test_name,"DLCO_RR") == 0) ||
+	     (strcasecmp(test_name,"DLCL_RR") == 0) ||
+	     (strcasecmp(test_name,"DLCO_STREAM") == 0) ||
+	     (strcasecmp(test_name,"DLCL_STREAM") == 0))
       {
 	scan_dlpi_args(argc, argv);
       }
 #endif /* DO_DLPI */
 #ifdef DO_UNIX
-    else if ((strcmp(test_name,"STREAM_RR") == 0) ||
-	     (strcmp(test_name,"DG_RR") == 0) ||
-	     (strcmp(test_name,"STREAM_STREAM") == 0) ||
-	     (strcmp(test_name,"DG_STREAM") == 0))
+    else if ((strcasecmp(test_name,"STREAM_RR") == 0) ||
+	     (strcasecmp(test_name,"DG_RR") == 0) ||
+	     (strcasecmp(test_name,"STREAM_STREAM") == 0) ||
+	     (strcasecmp(test_name,"DG_STREAM") == 0))
       {
 	scan_unix_args(argc, argv);
       }
 #endif /* DO_UNIX */
 #ifdef DO_FORE
-    else if ((strcmp(test_name,"FORE_RR") == 0) ||
-	     (strcmp(test_name,"FORE_STREAM") == 0))
+    else if ((strcasecmp(test_name,"FORE_RR") == 0) ||
+	     (strcasecmp(test_name,"FORE_STREAM") == 0))
       {
 	scan_fore_args(argc, argv);
       }
 #endif /* DO_FORE */
 #ifdef DO_HIPPI
-    else if ((strcmp(test_name,"HIPPI_RR") == 0) ||
-	     (strcmp(test_name,"HIPPI_STREAM") == 0))
+    else if ((strcasecmp(test_name,"HIPPI_RR") == 0) ||
+	     (strcasecmp(test_name,"HIPPI_STREAM") == 0))
       {
 	scan_hippi_args(argc, argv);
       }
 #endif /* DO_HIPPI */
 #ifdef DO_XTI
-    else if ((strcmp(test_name,"XTI_TCP_RR") == 0) ||
-	     (strcmp(test_name,"XTI_TCP_STREAM") == 0) ||
-	     (strcmp(test_name,"XTI_UDP_RR") == 0) ||
-	     (strcmp(test_name,"XTI_UDP_STREAM") == 0))
+    else if ((strcasecmp(test_name,"XTI_TCP_RR") == 0) ||
+	     (strcasecmp(test_name,"XTI_TCP_STREAM") == 0) ||
+	     (strcasecmp(test_name,"XTI_UDP_RR") == 0) ||
+	     (strcasecmp(test_name,"XTI_UDP_STREAM") == 0))
       {
 	scan_xti_args(argc, argv);
       }
 #endif /* DO_XTI */
 #ifdef DO_LWP
-    else if ((strcmp(test_name,"LWPSTR_RR") == 0) ||
-	     (strcmp(test_name,"LWPSTR_STREAM") == 0) ||
-	     (strcmp(test_name,"LWPDG_RR") == 0) ||
-	     (strcmp(test_name,"LWPDG_STREAM") == 0))
+    else if ((strcasecmp(test_name,"LWPSTR_RR") == 0) ||
+	     (strcasecmp(test_name,"LWPSTR_STREAM") == 0) ||
+	     (strcasecmp(test_name,"LWPDG_RR") == 0) ||
+	     (strcasecmp(test_name,"LWPDG_STREAM") == 0))
       {
 	scan_lwp_args(argc, argv);
       }
 #endif /* DO_LWP */
 #ifdef DO_IPV6
-    else if ((strcmp(test_name,"TCPIPV6_RR") == 0) ||
-	     (strcmp(test_name,"TCPIPV6_CRR") == 0) ||
-	     (strcmp(test_name,"TCPIPV6_STREAM") == 0) ||
-	     (strcmp(test_name,"UDPIPV6_RR") == 0) ||
-	     (strcmp(test_name,"UDPIPV6_STREAM") == 0))
+    else if ((strcasecmp(test_name,"TCPIPV6_RR") == 0) ||
+	     (strcasecmp(test_name,"TCPIPV6_CRR") == 0) ||
+	     (strcasecmp(test_name,"TCPIPV6_STREAM") == 0) ||
+	     (strcasecmp(test_name,"UDPIPV6_RR") == 0) ||
+	     (strcasecmp(test_name,"UDPIPV6_STREAM") == 0))
       {
 	scan_ipv6_args(argc, argv);
       }
 #endif /* DO_IPV6 */
+#ifdef DO_DNS
+    else if (strcasecmp(test_name,"DNS_RR") == 0)
+      {
+	scan_dns_args(argc, argv);
+      }
+#endif /* DO_DNS */
   }
+
+#ifdef DO_IPV6
+  /* address family check */   
+  if ((strcasecmp(test_name,"TCPIPV6_RR") == 0) ||
+      (strcasecmp(test_name,"TCPIPV6_CRR") == 0) ||
+      (strcasecmp(test_name,"TCPIPV6_STREAM") == 0) ||
+      (strcasecmp(test_name,"UDPIPV6_RR") == 0) ||
+      (strcasecmp(test_name,"UDPIPV6_STREAM") == 0))
+    {
+      af = AF_INET6;
+    }
+#endif /* DO_IPV6 */
 }
+
 
 void
 dump_globals()
